@@ -1,7 +1,7 @@
 # (c) Nelen & Schuurmans.  GPL licensed, see LICENSE.rst.
 # -*- coding: utf-8 -*-
 import logging
-from typing import List, Dict
+from typing import List, Dict, Optional
 from pathlib import Path
 
 from docker import DockerClient
@@ -62,6 +62,9 @@ def up(
     envs: Dict,
     labels: Dict,
     max_rate: float = 0.0,
+    clean_up_files: bool = False,
+    gridadmin_download_url: Optional[str] = None,
+    tables_download_url: Optional[str] = None
 ) -> str:
 
     """
@@ -84,7 +87,13 @@ def up(
     if hasattr(settings, "CONTAINER_LOG_LEVEL"):
         _envs += [f"LOG_LEVEL={settings.CONTAINER_LOG_LEVEL}"]
 
-    cmd = f"python service.py {settings.REDIS_HOST} {model_config} {sim_uid} {sim_ref_datetime} {end_time} {duration} {start_mode} {pause_timeout} {max_rate}" # noqa
+    cmd = f"python service.py {settings.REDIS_HOST} {model_config} {sim_uid} {sim_ref_datetime} {end_time} {duration} {start_mode} {pause_timeout} {max_rate} {clean_up_files}" # noqa
+
+    if gridadmin_download_url is not None:
+        cmd += f" {gridadmin_download_url}"
+    if tables_download_url is not None:
+        cmd += f" {tables_download_url}"
+
     logger.debug("cmd %s", cmd)
     logger.debug("Envs %s", _envs)
 
